@@ -871,9 +871,9 @@ class VentilationSetting(UmiBase):
                 key="ZONEVENTILATION:DESIGNFLOWRATE",
                 Name=f"{zone_name} Ventilation",
                 Zone_or_ZoneList_Name=zone_name,
-                Schedule_Name=self.ScheduledVentilationSchedule.to_year_week_day()[
-                    0
-                ].to_epbunch(idf).Name,  # take the YearSchedule and get the name.
+                Schedule_Name=self.ScheduledVentilationSchedule.to_year_week_day()[0]
+                .to_epbunch(idf)
+                .Name,  # take the YearSchedule and get the name.
                 Design_Flow_Rate_Calculation_Method="AirChanges/Hour",
                 Design_Flow_Rate="",
                 Flow_Rate_per_Zone_Floor_Area="",
